/* Terraform - (C) 1997-1999 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include "TFDialogPrintOptions.h"
#include "GlobalSanityCheck.h"
#include "GlobalTrace.h"
#include "MathTrig.h"
#include "TFWindowHandler.h"			// circular 
#include "PrintOptions.h"


/*
 *  TFDialogPrintOptions: provide a GUI interface to the print options
 * 	stored in PrintOptions.h
 */
TFDialogPrintOptions::TFDialogPrintOptions ()
	        : GuiDialogYN ("Terraform Print Options Dialog", "Print Options Parameters"),
		  d_hb1 (TRUE, 5),
		  d_hb2 (TRUE, 5),
		  d_hb3 (TRUE, 5),
		  d_hb4 (TRUE, 5),
		  d_hb5 (TRUE, 5),
		  d_vbMain (TRUE, 5),
		  d_lblPaperSize ("Paper Size"),
		  d_lblOrient ("Orientation"),
		  d_lblColor ("Colorspace"),
		  d_lblDummyColor (""),
		  d_lblMargins ("Page Margins"),
		  d_lblDummyMargins (""),
		  d_lblScaling ("Scale Factor"),
		  d_lblDummyScaling (""),
		  d_cbMargins ("Custom Margins"),
		  d_cbScaling ("Rescale")
			
{
	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "+++ TFDialogPrintOptions\n");

	d_cList = NULL;
	d_cmbPaperSize = d_cmbColor = NULL;
	d_glstPaperSize = d_glstColor = NULL;
	d_btnOrientLandscape = d_btnOrientPortrait = NULL;
	d_tblMargins = NULL;

	buildDialogWindow ();

	connect_to_method (d_cmbPaperSize->get_list()->selection_changed, this, &TFDialogPrintOptions::cmbPaperSizeCallback);

	//connect_to_method (d_adjFactor1->value_changed, this, &TFDialogPrintOptions::updatePreviewCallback);
	//connect_to_method (d_adjFactor2->value_changed, this, &TFDialogPrintOptions::updatePreviewCallback);
	//connect_to_method (d_cmbPaperSize->get_list()->selection_changed, this, &TFDialogPrintOptions::updatePreviewCallback);
	//connect_to_method (this->d_btnYes.clicked, this, &TFDialogPrintOptions::button1Callback);
	//connect_to_method (this->d_btnNo.clicked, this, &TFDialogPrintOptions::button2Callback);
	//connect_to_method (d_cList->button_press_event, this, &TFDialogPrintOptions::processCListButtonPress);
}


/*
 *  destructor: clean up 
 */
TFDialogPrintOptions::~TFDialogPrintOptions ()
{
	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "--- TFDialogPrintOptions\n");
}


/*
 *  insertPaperSize: insert the elemens for pape size selection
 */
void TFDialogPrintOptions::insertPaperSize ()
{
	d_hb1.pack_start (d_lblPaperSize, TRUE, TRUE, 0);
	d_lblPaperSize.show ();
	
	// build dropdown list of operations
	d_cmbPaperSize = new Gtk_Combo ();
	d_glstPaperSize = g_list_append (d_glstPaperSize, const_cast<char*>(MENU_PRINT_PAPER_LETTER));
	d_glstPaperSize = g_list_append (d_glstPaperSize, const_cast<char*>(MENU_PRINT_PAPER_A3));
	d_glstPaperSize = g_list_append (d_glstPaperSize, const_cast<char*>(MENU_PRINT_PAPER_A4));
	d_glstPaperSize = g_list_append (d_glstPaperSize, const_cast<char*>(MENU_PRINT_PAPER_A5));
	d_glstPaperSize = g_list_append (d_glstPaperSize, const_cast<char*>(MENU_PRINT_PAPER_CUSTOM));
	d_cmbPaperSize->set_popdown_strings (d_glstPaperSize);
	d_cmbPaperSize->get_entry()->set_text (MENU_PRINT_PAPER_LETTER);
	d_cmbPaperSize->get_entry()->set_editable (FALSE);
	d_hb1.pack_start (*d_cmbPaperSize, TRUE, TRUE, 0);
	d_cmbPaperSize->show ();

	d_hb1.pack_start (d_enPaperSize, TRUE, TRUE, 0);
	d_enPaperSize.show ();
	d_enPaperSize.set_sensitive (FALSE);

	d_vbMain.pack_start (d_hb1, TRUE, TRUE, 0);
	d_hb1.show ();
}


/*
 *  insertOrientation: insert the orientation choices
 */
void TFDialogPrintOptions::insertOrientation ()
{
	d_hb2.pack_start (d_lblOrient, TRUE, TRUE, 0);
	d_lblOrient.show ();

	d_btnOrientPortrait = new Gtk_RadioButton ((GSList *)NULL, "Portrait");
	d_btnOrientPortrait->set_active (TRUE);
	d_hb2.pack_start (*d_btnOrientPortrait, TRUE, TRUE, 0);
	d_btnOrientPortrait->show ();

	d_gslstOrient = d_btnOrientPortrait->group ();
	d_btnOrientLandscape = new Gtk_RadioButton (d_gslstOrient, "Landscape");
	d_btnOrientLandscape->set_active (FALSE);
	d_hb2.pack_start (*d_btnOrientLandscape, TRUE, TRUE, 0);
	d_btnOrientLandscape->show ();

	d_vbMain.pack_start (d_hb2, TRUE, TRUE, 0);
	d_hb2.show ();
}


/*
 *  insertColor: insert the elemens for colorspace selection
 */
void TFDialogPrintOptions::insertColor ()
{
	d_hb3.pack_start (d_lblColor, TRUE, TRUE, 0);
	d_lblColor.show ();
	
	// build dropdown list of operations
	d_cmbColor = new Gtk_Combo ();
	d_glstColor = g_list_append (d_glstColor, const_cast<char*>(MENU_PRINT_COLOR_MONO));
	d_glstColor = g_list_append (d_glstColor, const_cast<char*>(MENU_PRINT_COLOR_GRAY));
	d_glstColor = g_list_append (d_glstColor, const_cast<char*>(MENU_PRINT_COLOR_COLOR));
	d_cmbColor->set_popdown_strings (d_glstColor);
	d_cmbColor->get_entry()->set_text (MENU_PRINT_COLOR_COLOR);
	d_cmbColor->get_entry()->set_editable (FALSE);
	d_hb3.pack_start (*d_cmbColor, TRUE, TRUE, 0);
	d_cmbColor->show ();

	d_hb3.pack_start (d_lblDummyColor, TRUE, TRUE, 0);
	d_lblDummyColor.show ();
	d_lblDummyColor.set_sensitive (FALSE);

	d_vbMain.pack_start (d_hb3, TRUE, TRUE, 0);
	d_hb3.show ();
}


/*
 *  insertMargins: insert the elements for margin selection
 */
void TFDialogPrintOptions::insertMargins ()
{
	d_hb4.pack_start (d_lblMargins, TRUE, TRUE, 0);
	d_lblMargins.show ();

	d_cbMargins.set_active (FALSE);
	d_hb4.pack_start (d_cbMargins, TRUE, TRUE, 0);
	d_cbMargins.show ();

	d_hb4.pack_start (d_lblDummyMargins, TRUE, TRUE, 0);
	d_lblDummyMargins.show ();
	d_lblDummyMargins.set_sensitive (FALSE);

	d_vbMain.pack_start (d_hb4, TRUE, TRUE, 0);
	d_hb4.show ();
}


/*
 *  insertScaling: insert the elements for re-scale parameters
 */
void TFDialogPrintOptions::insertScaling ()
{
	d_hb5.pack_start (d_lblScaling, TRUE, TRUE, 0);
	d_lblScaling.show ();

	d_cbScaling.set_active (FALSE);
	d_hb5.pack_start (d_cbScaling, TRUE, TRUE, 0);
	d_cbScaling.show ();

	d_hb5.pack_start (d_lblDummyScaling, TRUE, TRUE, 0);
	d_lblDummyScaling.show ();
	d_lblDummyScaling.set_sensitive (FALSE);

	d_vbMain.pack_start (d_hb5, TRUE, TRUE, 0);
	d_hb5.show ();
}


/*
 *  buildDialogWindow: build the dialog window from it's components
 */
void TFDialogPrintOptions::buildDialogWindow ()
{
	this->set_usize (500, 400);
	this->set_title (this->d_winTitle);

	this->get_vbox()->set_border_width (2);
	setupVBox ();

	SanityCheck::bailout ((!this->d_baseFrame), "this->d_baseFrame==NULL", "TFDialogPrintOptions::buildDialogWindow");
	this->d_baseFrame->add (d_vbMain);

	insertPaperSize ();
	insertOrientation ();
	insertColor ();
	insertMargins ();
	insertScaling ();
	this->fillActionArea ();
	//rebuildCList ();

	d_vbMain.show ();
	this->show ();
}


/*
 *  buttonCallbackApply: roughen the Height Field
 */
void TFDialogPrintOptions::buttonCallbackYes ()
{
	string 		paperSize,
			color;
	char		orientation; 
	int		mTop, mBottom, mLeft, mRight,	// margins
			pWidth, pHeight,		// paper size 
			scaleFactor;

	paperSize = (d_cmbPaperSize->get_entry())->get_text();
	color = (d_cmbColor->get_entry())->get_text();

	if (d_btnOrientLandscape->get_active())
		orientation='L';
	else
		orientation='P';

	if (d_cbMargins.get_active())
		{
		}

	if (d_cbScaling.get_active())
		{
		}

	PrintOptions::s_paperSize = paperSize;
	PrintOptions::s_color = color[0];
	PrintOptions::s_orientation = orientation;

	if (paperSize == MENU_PRINT_PAPER_CUSTOM)
		{
		//PrintOptions::s_paperHeight = paperSize;
		//PrintOptions::s_paperWidth = paperSize;
		}

	// assign margins & scaling

	this->hide ();
}




/*
 *  cmbPaperSizeCallback: process a change in paper size selection 
 */
void TFDialogPrintOptions::cmbPaperSizeCallback ()
{
	string		entry;

	entry = (d_cmbPaperSize->get_entry())->get_text();

	if (entry == MENU_PRINT_PAPER_CUSTOM)
		d_enPaperSize.set_sensitive (TRUE);
	else
		d_enPaperSize.set_sensitive (FALSE);
		
}


